@@ -31,7 +31,7 @@ import datetime
 import time
 import collections
 
-VERSION = (0, 3, 8)
+VERSION = (0, 4, 0)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -548,6 +548,10 @@ class Connection(object):
                     for i in range(count):
                         name = data[n:n+data[n:].find(b'\x00')]
                         n += len(name) + 1
+                        try:
+                            name = name.decode(self.encoding)
+                        except UnicodeDecodeError:
+                            pass
                         type_code = _bytes_to_bint(data[n+6:n+10])
                         if type_code == PG_TYPE_VARCHAR:
                             size = _bytes_to_bint(data[n+12:n+16]) - 4
